@@ -5,11 +5,12 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_18.core_v1 import EventSource  # noqa: F401
-from kuber.v1_18.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_18.meta_v1 import MicroTime  # noqa: F401
-from kuber.v1_18.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_18.core_v1 import ObjectReference  # noqa: F401
+from kuber import _types  # noqa: F401
+from kuber.v1_15.core_v1 import EventSource  # noqa: F401
+from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_15.meta_v1 import MicroTime  # noqa: F401
+from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_15.core_v1 import ObjectReference  # noqa: F401
 
 
 class Event(_kuber_definitions.Resource):
@@ -580,8 +581,8 @@ class EventList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -592,8 +593,8 @@ class EventList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
