@@ -5,12 +5,13 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_21.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_21.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_21.core_v1 import PersistentVolumeSpec  # noqa: F401
-from kuber.v1_21.meta_v1 import Status  # noqa: F401
-from kuber.v1_21.meta_v1 import StatusDetails  # noqa: F401
-from kuber.v1_21.core_v1 import TopologySelectorTerm  # noqa: F401
+from kuber import _types  # noqa: F401
+from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_15.core_v1 import PersistentVolumeSpec  # noqa: F401
+from kuber.v1_15.meta_v1 import Status  # noqa: F401
+from kuber.v1_15.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_15.core_v1 import TopologySelectorTerm  # noqa: F401
 
 
 class CSIDriver(_kuber_definitions.Resource):
@@ -55,8 +56,8 @@ class CSIDriver(_kuber_definitions.Resource):
         beginning and ending with an alphanumeric character
         ([a-z0-9A-Z]) with dashes (-), dots (.), and alphanumerics
         between. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -73,8 +74,8 @@ class CSIDriver(_kuber_definitions.Resource):
         beginning and ending with an alphanumeric character
         ([a-z0-9A-Z]) with dashes (-), dots (.), and alphanumerics
         between. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -277,8 +278,8 @@ class CSIDriverList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -289,8 +290,8 @@ class CSIDriverList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -326,12 +327,7 @@ class CSIDriverSpec(_kuber_definitions.Definition):
     def __init__(
         self,
         attach_required: bool = None,
-        fs_group_policy: str = None,
         pod_info_on_mount: bool = None,
-        requires_republish: bool = None,
-        storage_capacity: bool = None,
-        token_requests: typing.List["TokenRequest"] = None,
-        volume_lifecycle_modes: typing.List[str] = None,
     ):
         """Create CSIDriverSpec instance."""
         super(CSIDriverSpec, self).__init__(
@@ -339,29 +335,13 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         )
         self._properties = {
             "attachRequired": attach_required if attach_required is not None else None,
-            "fsGroupPolicy": fs_group_policy if fs_group_policy is not None else "",
             "podInfoOnMount": pod_info_on_mount
             if pod_info_on_mount is not None
             else None,
-            "requiresRepublish": requires_republish
-            if requires_republish is not None
-            else None,
-            "storageCapacity": storage_capacity
-            if storage_capacity is not None
-            else None,
-            "tokenRequests": token_requests if token_requests is not None else [],
-            "volumeLifecycleModes": volume_lifecycle_modes
-            if volume_lifecycle_modes is not None
-            else [],
         }
         self._types = {
             "attachRequired": (bool, None),
-            "fsGroupPolicy": (str, None),
             "podInfoOnMount": (bool, None),
-            "requiresRepublish": (bool, None),
-            "storageCapacity": (bool, None),
-            "tokenRequests": (list, TokenRequest),
-            "volumeLifecycleModes": (list, str),
         }
 
     @property
@@ -403,31 +383,6 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         """
         self._properties["attachRequired"] = value
 
-    @property
-    def fs_group_policy(self) -> str:
-        """
-        Defines if the underlying volume supports changing ownership
-        and permission of the volume before being mounted. Refer to
-        the specific FSGroupPolicy values for additional details.
-        This field is alpha-level, and is only honored by servers
-        that enable the CSIVolumeFSGroupPolicy feature gate.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("fsGroupPolicy"),
-        )
-
-    @fs_group_policy.setter
-    def fs_group_policy(self, value: str):
-        """
-        Defines if the underlying volume supports changing ownership
-        and permission of the volume before being mounted. Refer to
-        the specific FSGroupPolicy values for additional details.
-        This field is alpha-level, and is only honored by servers
-        that enable the CSIVolumeFSGroupPolicy feature gate.
-        """
-        self._properties["fsGroupPolicy"] = value
-
     @property
     def pod_info_on_mount(self) -> bool:
         """
@@ -445,20 +400,6 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         "csi.storage.k8s.io/pod.name": pod.Name
         "csi.storage.k8s.io/pod.namespace": pod.Namespace
         "csi.storage.k8s.io/pod.uid": string(pod.UID)
-        "csi.storage.k8s.io/ephemeral": "true" iff the volume is an
-        ephemeral inline volume
-                                        defined by a
-        CSIVolumeSource, otherwise "false"
-
-        "csi.storage.k8s.io/ephemeral" is a new feature in
-        Kubernetes 1.16. It is only required for drivers which
-        support both the "Persistent" and "Ephemeral"
-        VolumeLifecycleMode. Other drivers can leave pod info
-        disabled and/or ignore this field. As Kubernetes 1.15
-        doesn't support this field, drivers can only support one
-        mode when deployed on such a cluster and the deployment
-        determines which mode that is, for example via a command
-        line parameter of the driver.
         """
         return typing.cast(
             bool,
@@ -482,217 +423,9 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         "csi.storage.k8s.io/pod.name": pod.Name
         "csi.storage.k8s.io/pod.namespace": pod.Namespace
         "csi.storage.k8s.io/pod.uid": string(pod.UID)
-        "csi.storage.k8s.io/ephemeral": "true" iff the volume is an
-        ephemeral inline volume
-                                        defined by a
-        CSIVolumeSource, otherwise "false"
-
-        "csi.storage.k8s.io/ephemeral" is a new feature in
-        Kubernetes 1.16. It is only required for drivers which
-        support both the "Persistent" and "Ephemeral"
-        VolumeLifecycleMode. Other drivers can leave pod info
-        disabled and/or ignore this field. As Kubernetes 1.15
-        doesn't support this field, drivers can only support one
-        mode when deployed on such a cluster and the deployment
-        determines which mode that is, for example via a command
-        line parameter of the driver.
         """
         self._properties["podInfoOnMount"] = value
 
-    @property
-    def requires_republish(self) -> bool:
-        """
-        RequiresRepublish indicates the CSI driver wants
-        `NodePublishVolume` being periodically called to reflect any
-        possible change in the mounted volume. This field defaults
-        to false.
-
-        Note: After a successful initial NodePublishVolume call,
-        subsequent calls to NodePublishVolume should only update the
-        contents of the volume. New mount points will not be seen by
-        a running container.
-
-        This is an alpha feature and only available when the
-        CSIServiceAccountToken feature is enabled.
-        """
-        return typing.cast(
-            bool,
-            self._properties.get("requiresRepublish"),
-        )
-
-    @requires_republish.setter
-    def requires_republish(self, value: bool):
-        """
-        RequiresRepublish indicates the CSI driver wants
-        `NodePublishVolume` being periodically called to reflect any
-        possible change in the mounted volume. This field defaults
-        to false.
-
-        Note: After a successful initial NodePublishVolume call,
-        subsequent calls to NodePublishVolume should only update the
-        contents of the volume. New mount points will not be seen by
-        a running container.
-
-        This is an alpha feature and only available when the
-        CSIServiceAccountToken feature is enabled.
-        """
-        self._properties["requiresRepublish"] = value
-
-    @property
-    def storage_capacity(self) -> bool:
-        """
-        If set to true, storageCapacity indicates that the CSI
-        volume driver wants pod scheduling to consider the storage
-        capacity that the driver deployment will report by creating
-        CSIStorageCapacity objects with capacity information.
-
-        The check can be enabled immediately when deploying a
-        driver. In that case, provisioning new volumes with late
-        binding will pause until the driver deployment has published
-        some suitable CSIStorageCapacity object.
-
-        Alternatively, the driver can be deployed with the field
-        unset or false and it can be flipped later when storage
-        capacity information has been published.
-
-        This is an alpha field and only available when the
-        CSIStorageCapacity feature is enabled. The default is false.
-        """
-        return typing.cast(
-            bool,
-            self._properties.get("storageCapacity"),
-        )
-
-    @storage_capacity.setter
-    def storage_capacity(self, value: bool):
-        """
-        If set to true, storageCapacity indicates that the CSI
-        volume driver wants pod scheduling to consider the storage
-        capacity that the driver deployment will report by creating
-        CSIStorageCapacity objects with capacity information.
-
-        The check can be enabled immediately when deploying a
-        driver. In that case, provisioning new volumes with late
-        binding will pause until the driver deployment has published
-        some suitable CSIStorageCapacity object.
-
-        Alternatively, the driver can be deployed with the field
-        unset or false and it can be flipped later when storage
-        capacity information has been published.
-
-        This is an alpha field and only available when the
-        CSIStorageCapacity feature is enabled. The default is false.
-        """
-        self._properties["storageCapacity"] = value
-
-    @property
-    def token_requests(self) -> typing.List["TokenRequest"]:
-        """
-        TokenRequests indicates the CSI driver needs pods' service
-        account tokens it is mounting volume for to do necessary
-        authentication. Kubelet will pass the tokens in
-        VolumeContext in the CSI NodePublishVolume calls. The CSI
-        driver should parse and validate the following
-        VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
-          "<audience>": {
-            "token": <token>,
-            "expirationTimestamp": <expiration timestamp in
-        RFC3339>,
-          },
-          ...
-        }
-
-        Note: Audience in each TokenRequest should be different and
-        at most one token is empty string. To receive a new token
-        after expiry, RequiresRepublish can be used to trigger
-        NodePublishVolume periodically.
-
-        This is an alpha feature and only available when the
-        CSIServiceAccountToken feature is enabled.
-        """
-        return typing.cast(
-            typing.List["TokenRequest"],
-            self._properties.get("tokenRequests"),
-        )
-
-    @token_requests.setter
-    def token_requests(
-        self, value: typing.Union[typing.List["TokenRequest"], typing.List[dict]]
-    ):
-        """
-        TokenRequests indicates the CSI driver needs pods' service
-        account tokens it is mounting volume for to do necessary
-        authentication. Kubelet will pass the tokens in
-        VolumeContext in the CSI NodePublishVolume calls. The CSI
-        driver should parse and validate the following
-        VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
-          "<audience>": {
-            "token": <token>,
-            "expirationTimestamp": <expiration timestamp in
-        RFC3339>,
-          },
-          ...
-        }
-
-        Note: Audience in each TokenRequest should be different and
-        at most one token is empty string. To receive a new token
-        after expiry, RequiresRepublish can be used to trigger
-        NodePublishVolume periodically.
-
-        This is an alpha feature and only available when the
-        CSIServiceAccountToken feature is enabled.
-        """
-        cleaned: typing.List[TokenRequest] = []
-        for item in value:
-            if isinstance(item, dict):
-                item = typing.cast(
-                    TokenRequest,
-                    TokenRequest().from_dict(item),
-                )
-            cleaned.append(typing.cast(TokenRequest, item))
-        self._properties["tokenRequests"] = cleaned
-
-    @property
-    def volume_lifecycle_modes(self) -> typing.List[str]:
-        """
-        VolumeLifecycleModes defines what kind of volumes this CSI
-        volume driver supports. The default if the list is empty is
-        "Persistent", which is the usage defined by the CSI
-        specification and implemented in Kubernetes via the usual
-        PV/PVC mechanism. The other mode is "Ephemeral". In this
-        mode, volumes are defined inline inside the pod spec with
-        CSIVolumeSource and their lifecycle is tied to the lifecycle
-        of that pod. A driver has to be aware of this because it is
-        only going to get a NodePublishVolume call for such a
-        volume. For more information about implementing this mode,
-        see https://kubernetes-csi.github.io/docs/ephemeral-local-
-        volumes.html A driver can support one or more of these modes
-        and more modes may be added in the future.
-        """
-        return typing.cast(
-            typing.List[str],
-            self._properties.get("volumeLifecycleModes"),
-        )
-
-    @volume_lifecycle_modes.setter
-    def volume_lifecycle_modes(self, value: typing.List[str]):
-        """
-        VolumeLifecycleModes defines what kind of volumes this CSI
-        volume driver supports. The default if the list is empty is
-        "Persistent", which is the usage defined by the CSI
-        specification and implemented in Kubernetes via the usual
-        PV/PVC mechanism. The other mode is "Ephemeral". In this
-        mode, volumes are defined inline inside the pod spec with
-        CSIVolumeSource and their lifecycle is tied to the lifecycle
-        of that pod. A driver has to be aware of this because it is
-        only going to get a NodePublishVolume call for such a
-        volume. For more information about implementing this mode,
-        see https://kubernetes-csi.github.io/docs/ephemeral-local-
-        volumes.html A driver can support one or more of these modes
-        and more modes may be added in the future.
-        """
-        self._properties["volumeLifecycleModes"] = value
-
     def __enter__(self) -> "CSIDriverSpec":
         return self
 
@@ -702,19 +435,16 @@ class CSIDriverSpec(_kuber_definitions.Definition):
 
 class CSINode(_kuber_definitions.Resource):
     """
-    DEPRECATED - This group version of CSINode is deprecated by
-    storage/v1/CSINode. See the release notes for more
-    information. CSINode holds information about all CSI drivers
-    installed on a node. CSI drivers do not need to create the
-    CSINode object directly. As long as they use the node-
-    driver-registrar sidecar container, the kubelet will
-    automatically populate the CSINode object for the CSI driver
-    as part of kubelet plugin registration. CSINode has the same
-    name as a node. If the object is missing, it means either
-    there are no CSI Drivers available on the node, or the
-    Kubelet version is low enough that it doesn't create this
-    object. CSINode has an OwnerReference that points to the
-    corresponding node object.
+    CSINode holds information about all CSI drivers installed on
+    a node. CSI drivers do not need to create the CSINode object
+    directly. As long as they use the node-driver-registrar
+    sidecar container, the kubelet will automatically populate
+    the CSINode object for the CSI driver as part of kubelet
+    plugin registration. CSINode has the same name as a node. If
+    the object is missing, it means either there are no CSI
+    Drivers available on the node, or the Kubelet version is low
+    enough that it doesn't create this object. CSINode has an
+    OwnerReference that points to the corresponding node object.
     """
 
     def __init__(
@@ -905,7 +635,6 @@ class CSINodeDriver(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        allocatable: "VolumeNodeResources" = None,
         name: str = None,
         node_id: str = None,
         topology_keys: typing.List[str] = None,
@@ -915,44 +644,16 @@ class CSINodeDriver(_kuber_definitions.Definition):
             api_version="storage/v1beta1", kind="CSINodeDriver"
         )
         self._properties = {
-            "allocatable": allocatable
-            if allocatable is not None
-            else VolumeNodeResources(),
             "name": name if name is not None else "",
             "nodeID": node_id if node_id is not None else "",
             "topologyKeys": topology_keys if topology_keys is not None else [],
         }
         self._types = {
-            "allocatable": (VolumeNodeResources, None),
             "name": (str, None),
             "nodeID": (str, None),
             "topologyKeys": (list, str),
         }
 
-    @property
-    def allocatable(self) -> "VolumeNodeResources":
-        """
-        allocatable represents the volume resources of a node that
-        are available for scheduling.
-        """
-        return typing.cast(
-            "VolumeNodeResources",
-            self._properties.get("allocatable"),
-        )
-
-    @allocatable.setter
-    def allocatable(self, value: typing.Union["VolumeNodeResources", dict]):
-        """
-        allocatable represents the volume resources of a node that
-        are available for scheduling.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                VolumeNodeResources,
-                VolumeNodeResources().from_dict(value),
-            )
-        self._properties["allocatable"] = value
-
     @property
     def name(self) -> str:
         """
@@ -1109,8 +810,8 @@ class CSINodeList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -1121,8 +822,8 @@ class CSINodeList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1323,8 +1024,8 @@ class StorageClass(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -1335,8 +1036,8 @@ class StorageClass(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1622,8 +1323,8 @@ class StorageClassList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -1634,8 +1335,8 @@ class StorageClassList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1663,80 +1364,6 @@ class StorageClassList(_kuber_definitions.Collection):
         return False
 
 
-class TokenRequest(_kuber_definitions.Definition):
-    """
-    TokenRequest contains parameters of a service account token.
-    """
-
-    def __init__(
-        self,
-        audience: str = None,
-        expiration_seconds: int = None,
-    ):
-        """Create TokenRequest instance."""
-        super(TokenRequest, self).__init__(
-            api_version="storage/v1beta1", kind="TokenRequest"
-        )
-        self._properties = {
-            "audience": audience if audience is not None else "",
-            "expirationSeconds": expiration_seconds
-            if expiration_seconds is not None
-            else None,
-        }
-        self._types = {
-            "audience": (str, None),
-            "expirationSeconds": (int, None),
-        }
-
-    @property
-    def audience(self) -> str:
-        """
-        Audience is the intended audience of the token in
-        "TokenRequestSpec". It will default to the audiences of kube
-        apiserver.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("audience"),
-        )
-
-    @audience.setter
-    def audience(self, value: str):
-        """
-        Audience is the intended audience of the token in
-        "TokenRequestSpec". It will default to the audiences of kube
-        apiserver.
-        """
-        self._properties["audience"] = value
-
-    @property
-    def expiration_seconds(self) -> int:
-        """
-        ExpirationSeconds is the duration of validity of the token
-        in "TokenRequestSpec". It has the same default value of
-        "ExpirationSeconds" in "TokenRequestSpec"
-        """
-        return typing.cast(
-            int,
-            self._properties.get("expirationSeconds"),
-        )
-
-    @expiration_seconds.setter
-    def expiration_seconds(self, value: int):
-        """
-        ExpirationSeconds is the duration of validity of the token
-        in "TokenRequestSpec". It has the same default value of
-        "ExpirationSeconds" in "TokenRequestSpec"
-        """
-        self._properties["expirationSeconds"] = value
-
-    def __enter__(self) -> "TokenRequest":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
 class VolumeAttachment(_kuber_definitions.Resource):
     """
     VolumeAttachment captures the intent to attach or detach the
@@ -1772,8 +1399,8 @@ class VolumeAttachment(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         Standard object metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -1784,8 +1411,8 @@ class VolumeAttachment(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         Standard object metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -2056,8 +1683,8 @@ class VolumeAttachmentList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -2068,8 +1695,8 @@ class VolumeAttachmentList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -2487,60 +2114,3 @@ class VolumeError(_kuber_definitions.Definition):
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         return False
-
-
-class VolumeNodeResources(_kuber_definitions.Definition):
-    """
-    VolumeNodeResources is a set of resource limits for
-    scheduling of volumes.
-    """
-
-    def __init__(
-        self,
-        count: int = None,
-    ):
-        """Create VolumeNodeResources instance."""
-        super(VolumeNodeResources, self).__init__(
-            api_version="storage/v1beta1", kind="VolumeNodeResources"
-        )
-        self._properties = {
-            "count": count if count is not None else None,
-        }
-        self._types = {
-            "count": (int, None),
-        }
-
-    @property
-    def count(self) -> int:
-        """
-        Maximum number of unique volumes managed by the CSI driver
-        that can be used on a node. A volume that is both attached
-        and mounted on a node is considered to be used once, not
-        twice. The same rule applies for a unique volume that is
-        shared among multiple pods on the same node. If this field
-        is nil, then the supported number of volumes on this node is
-        unbounded.
-        """
-        return typing.cast(
-            int,
-            self._properties.get("count"),
-        )
-
-    @count.setter
-    def count(self, value: int):
-        """
-        Maximum number of unique volumes managed by the CSI driver
-        that can be used on a node. A volume that is both attached
-        and mounted on a node is considered to be used once, not
-        twice. The same rule applies for a unique volume that is
-        shared among multiple pods on the same node. If this field
-        is nil, then the supported number of volumes on this node is
-        unbounded.
-        """
-        self._properties["count"] = value
-
-    def __enter__(self) -> "VolumeNodeResources":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
