@@ -5,207 +5,12 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_20.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import Status  # noqa: F401
-from kuber.v1_20.meta_v1 import StatusDetails  # noqa: F401
-
-
-class ContainerResourceMetricSource(_kuber_definitions.Definition):
-    """
-    ContainerResourceMetricSource indicates how to scale on a
-    resource metric known to Kubernetes, as specified in
-    requests and limits, describing each pod in the current
-    scale target (e.g. CPU or memory).  The values will be
-    averaged together before being compared to the target.  Such
-    metrics are built in to Kubernetes, and have special scaling
-    options on top of those available to normal per-pod metrics
-    using the "pods" source.  Only one "target" type should be
-    set.
-    """
-
-    def __init__(
-        self,
-        container: str = None,
-        name: str = None,
-        target: "MetricTarget" = None,
-    ):
-        """Create ContainerResourceMetricSource instance."""
-        super(ContainerResourceMetricSource, self).__init__(
-            api_version="autoscaling/v2beta2", kind="ContainerResourceMetricSource"
-        )
-        self._properties = {
-            "container": container if container is not None else "",
-            "name": name if name is not None else "",
-            "target": target if target is not None else MetricTarget(),
-        }
-        self._types = {
-            "container": (str, None),
-            "name": (str, None),
-            "target": (MetricTarget, None),
-        }
-
-    @property
-    def container(self) -> str:
-        """
-        container is the name of the container in the pods of the
-        scaling target
-        """
-        return typing.cast(
-            str,
-            self._properties.get("container"),
-        )
-
-    @container.setter
-    def container(self, value: str):
-        """
-        container is the name of the container in the pods of the
-        scaling target
-        """
-        self._properties["container"] = value
-
-    @property
-    def name(self) -> str:
-        """
-        name is the name of the resource in question.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("name"),
-        )
-
-    @name.setter
-    def name(self, value: str):
-        """
-        name is the name of the resource in question.
-        """
-        self._properties["name"] = value
-
-    @property
-    def target(self) -> "MetricTarget":
-        """
-        target specifies the target value for the given metric
-        """
-        return typing.cast(
-            "MetricTarget",
-            self._properties.get("target"),
-        )
-
-    @target.setter
-    def target(self, value: typing.Union["MetricTarget", dict]):
-        """
-        target specifies the target value for the given metric
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                MetricTarget,
-                MetricTarget().from_dict(value),
-            )
-        self._properties["target"] = value
-
-    def __enter__(self) -> "ContainerResourceMetricSource":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
-class ContainerResourceMetricStatus(_kuber_definitions.Definition):
-    """
-    ContainerResourceMetricStatus indicates the current value of
-    a resource metric known to Kubernetes, as specified in
-    requests and limits, describing a single container in each
-    pod in the current scale target (e.g. CPU or memory).  Such
-    metrics are built in to Kubernetes, and have special scaling
-    options on top of those available to normal per-pod metrics
-    using the "pods" source.
-    """
-
-    def __init__(
-        self,
-        container: str = None,
-        current: "MetricValueStatus" = None,
-        name: str = None,
-    ):
-        """Create ContainerResourceMetricStatus instance."""
-        super(ContainerResourceMetricStatus, self).__init__(
-            api_version="autoscaling/v2beta2", kind="ContainerResourceMetricStatus"
-        )
-        self._properties = {
-            "container": container if container is not None else "",
-            "current": current if current is not None else MetricValueStatus(),
-            "name": name if name is not None else "",
-        }
-        self._types = {
-            "container": (str, None),
-            "current": (MetricValueStatus, None),
-            "name": (str, None),
-        }
-
-    @property
-    def container(self) -> str:
-        """
-        Container is the name of the container in the pods of the
-        scaling target
-        """
-        return typing.cast(
-            str,
-            self._properties.get("container"),
-        )
-
-    @container.setter
-    def container(self, value: str):
-        """
-        Container is the name of the container in the pods of the
-        scaling target
-        """
-        self._properties["container"] = value
-
-    @property
-    def current(self) -> "MetricValueStatus":
-        """
-        current contains the current value for the given metric
-        """
-        return typing.cast(
-            "MetricValueStatus",
-            self._properties.get("current"),
-        )
-
-    @current.setter
-    def current(self, value: typing.Union["MetricValueStatus", dict]):
-        """
-        current contains the current value for the given metric
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                MetricValueStatus,
-                MetricValueStatus().from_dict(value),
-            )
-        self._properties["current"] = value
-
-    @property
-    def name(self) -> str:
-        """
-        Name is the name of the resource in question.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("name"),
-        )
-
-    @name.setter
-    def name(self, value: str):
-        """
-        Name is the name of the resource in question.
-        """
-        self._properties["name"] = value
-
-    def __enter__(self) -> "ContainerResourceMetricStatus":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
+from kuber import _types  # noqa: F401
+from kuber.v1_16.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_16.meta_v1 import Status  # noqa: F401
+from kuber.v1_16.meta_v1 import StatusDetails  # noqa: F401
 
 
 class CrossVersionObjectReference(_kuber_definitions.Definition):
@@ -451,219 +256,6 @@ class ExternalMetricStatus(_kuber_definitions.Definition):
         return False
 
 
-class HPAScalingPolicy(_kuber_definitions.Definition):
-    """
-    HPAScalingPolicy is a single policy which must hold true for
-    a specified past interval.
-    """
-
-    def __init__(
-        self,
-        period_seconds: int = None,
-        type_: str = None,
-        value: int = None,
-    ):
-        """Create HPAScalingPolicy instance."""
-        super(HPAScalingPolicy, self).__init__(
-            api_version="autoscaling/v2beta2", kind="HPAScalingPolicy"
-        )
-        self._properties = {
-            "periodSeconds": period_seconds if period_seconds is not None else None,
-            "type": type_ if type_ is not None else "",
-            "value": value if value is not None else None,
-        }
-        self._types = {
-            "periodSeconds": (int, None),
-            "type": (str, None),
-            "value": (int, None),
-        }
-
-    @property
-    def period_seconds(self) -> int:
-        """
-        PeriodSeconds specifies the window of time for which the
-        policy should hold true. PeriodSeconds must be greater than
-        zero and less than or equal to 1800 (30 min).
-        """
-        return typing.cast(
-            int,
-            self._properties.get("periodSeconds"),
-        )
-
-    @period_seconds.setter
-    def period_seconds(self, value: int):
-        """
-        PeriodSeconds specifies the window of time for which the
-        policy should hold true. PeriodSeconds must be greater than
-        zero and less than or equal to 1800 (30 min).
-        """
-        self._properties["periodSeconds"] = value
-
-    @property
-    def type_(self) -> str:
-        """
-        Type is used to specify the scaling policy.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("type"),
-        )
-
-    @type_.setter
-    def type_(self, value: str):
-        """
-        Type is used to specify the scaling policy.
-        """
-        self._properties["type"] = value
-
-    @property
-    def value(self) -> int:
-        """
-        Value contains the amount of change which is permitted by
-        the policy. It must be greater than zero
-        """
-        return typing.cast(
-            int,
-            self._properties.get("value"),
-        )
-
-    @value.setter
-    def value(self, value: int):
-        """
-        Value contains the amount of change which is permitted by
-        the policy. It must be greater than zero
-        """
-        self._properties["value"] = value
-
-    def __enter__(self) -> "HPAScalingPolicy":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
-class HPAScalingRules(_kuber_definitions.Definition):
-    """
-    HPAScalingRules configures the scaling behavior for one
-    direction. These Rules are applied after calculating
-    DesiredReplicas from metrics for the HPA. They can limit the
-    scaling velocity by specifying scaling policies. They can
-    prevent flapping by specifying the stabilization window, so
-    that the number of replicas is not set instantly, instead,
-    the safest value from the stabilization window is chosen.
-    """
-
-    def __init__(
-        self,
-        policies: typing.List["HPAScalingPolicy"] = None,
-        select_policy: str = None,
-        stabilization_window_seconds: int = None,
-    ):
-        """Create HPAScalingRules instance."""
-        super(HPAScalingRules, self).__init__(
-            api_version="autoscaling/v2beta2", kind="HPAScalingRules"
-        )
-        self._properties = {
-            "policies": policies if policies is not None else [],
-            "selectPolicy": select_policy if select_policy is not None else "",
-            "stabilizationWindowSeconds": stabilization_window_seconds
-            if stabilization_window_seconds is not None
-            else None,
-        }
-        self._types = {
-            "policies": (list, HPAScalingPolicy),
-            "selectPolicy": (str, None),
-            "stabilizationWindowSeconds": (int, None),
-        }
-
-    @property
-    def policies(self) -> typing.List["HPAScalingPolicy"]:
-        """
-        policies is a list of potential scaling polices which can be
-        used during scaling. At least one policy must be specified,
-        otherwise the HPAScalingRules will be discarded as invalid
-        """
-        return typing.cast(
-            typing.List["HPAScalingPolicy"],
-            self._properties.get("policies"),
-        )
-
-    @policies.setter
-    def policies(
-        self, value: typing.Union[typing.List["HPAScalingPolicy"], typing.List[dict]]
-    ):
-        """
-        policies is a list of potential scaling polices which can be
-        used during scaling. At least one policy must be specified,
-        otherwise the HPAScalingRules will be discarded as invalid
-        """
-        cleaned: typing.List[HPAScalingPolicy] = []
-        for item in value:
-            if isinstance(item, dict):
-                item = typing.cast(
-                    HPAScalingPolicy,
-                    HPAScalingPolicy().from_dict(item),
-                )
-            cleaned.append(typing.cast(HPAScalingPolicy, item))
-        self._properties["policies"] = cleaned
-
-    @property
-    def select_policy(self) -> str:
-        """
-        selectPolicy is used to specify which policy should be used.
-        If not set, the default value MaxPolicySelect is used.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("selectPolicy"),
-        )
-
-    @select_policy.setter
-    def select_policy(self, value: str):
-        """
-        selectPolicy is used to specify which policy should be used.
-        If not set, the default value MaxPolicySelect is used.
-        """
-        self._properties["selectPolicy"] = value
-
-    @property
-    def stabilization_window_seconds(self) -> int:
-        """
-        StabilizationWindowSeconds is the number of seconds for
-        which past recommendations should be considered while
-        scaling up or scaling down. StabilizationWindowSeconds must
-        be greater than or equal to zero and less than or equal to
-        3600 (one hour). If not set, use the default values: - For
-        scale up: 0 (i.e. no stabilization is done). - For scale
-        down: 300 (i.e. the stabilization window is 300 seconds
-        long).
-        """
-        return typing.cast(
-            int,
-            self._properties.get("stabilizationWindowSeconds"),
-        )
-
-    @stabilization_window_seconds.setter
-    def stabilization_window_seconds(self, value: int):
-        """
-        StabilizationWindowSeconds is the number of seconds for
-        which past recommendations should be considered while
-        scaling up or scaling down. StabilizationWindowSeconds must
-        be greater than or equal to zero and less than or equal to
-        3600 (one hour). If not set, use the default values: - For
-        scale up: 0 (i.e. no stabilization is done). - For scale
-        down: 300 (i.e. the stabilization window is 300 seconds
-        long).
-        """
-        self._properties["stabilizationWindowSeconds"] = value
-
-    def __enter__(self) -> "HPAScalingRules":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
 class HorizontalPodAutoscaler(_kuber_definitions.Resource):
     """
     HorizontalPodAutoscaler is the configuration for a
@@ -943,96 +535,6 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         return False
 
 
-class HorizontalPodAutoscalerBehavior(_kuber_definitions.Definition):
-    """
-    HorizontalPodAutoscalerBehavior configures the scaling
-    behavior of the target in both Up and Down directions
-    (scaleUp and scaleDown fields respectively).
-    """
-
-    def __init__(
-        self,
-        scale_down: "HPAScalingRules" = None,
-        scale_up: "HPAScalingRules" = None,
-    ):
-        """Create HorizontalPodAutoscalerBehavior instance."""
-        super(HorizontalPodAutoscalerBehavior, self).__init__(
-            api_version="autoscaling/v2beta2", kind="HorizontalPodAutoscalerBehavior"
-        )
-        self._properties = {
-            "scaleDown": scale_down if scale_down is not None else HPAScalingRules(),
-            "scaleUp": scale_up if scale_up is not None else HPAScalingRules(),
-        }
-        self._types = {
-            "scaleDown": (HPAScalingRules, None),
-            "scaleUp": (HPAScalingRules, None),
-        }
-
-    @property
-    def scale_down(self) -> "HPAScalingRules":
-        """
-        scaleDown is scaling policy for scaling Down. If not set,
-        the default value is to allow to scale down to minReplicas
-        pods, with a 300 second stabilization window (i.e., the
-        highest recommendation for the last 300sec is used).
-        """
-        return typing.cast(
-            "HPAScalingRules",
-            self._properties.get("scaleDown"),
-        )
-
-    @scale_down.setter
-    def scale_down(self, value: typing.Union["HPAScalingRules", dict]):
-        """
-        scaleDown is scaling policy for scaling Down. If not set,
-        the default value is to allow to scale down to minReplicas
-        pods, with a 300 second stabilization window (i.e., the
-        highest recommendation for the last 300sec is used).
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                HPAScalingRules,
-                HPAScalingRules().from_dict(value),
-            )
-        self._properties["scaleDown"] = value
-
-    @property
-    def scale_up(self) -> "HPAScalingRules":
-        """
-        scaleUp is scaling policy for scaling Up. If not set, the
-        default value is the higher of:
-          * increase no more than 4 pods per 60 seconds
-          * double the number of pods per 60 seconds
-        No stabilization is used.
-        """
-        return typing.cast(
-            "HPAScalingRules",
-            self._properties.get("scaleUp"),
-        )
-
-    @scale_up.setter
-    def scale_up(self, value: typing.Union["HPAScalingRules", dict]):
-        """
-        scaleUp is scaling policy for scaling Up. If not set, the
-        default value is the higher of:
-          * increase no more than 4 pods per 60 seconds
-          * double the number of pods per 60 seconds
-        No stabilization is used.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                HPAScalingRules,
-                HPAScalingRules().from_dict(value),
-            )
-        self._properties["scaleUp"] = value
-
-    def __enter__(self) -> "HorizontalPodAutoscalerBehavior":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
 class HorizontalPodAutoscalerCondition(_kuber_definitions.Definition):
     """
     HorizontalPodAutoscalerCondition describes the state of a
@@ -1273,7 +775,6 @@ class HorizontalPodAutoscalerSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        behavior: "HorizontalPodAutoscalerBehavior" = None,
         max_replicas: int = None,
         metrics: typing.List["MetricSpec"] = None,
         min_replicas: int = None,
@@ -1284,9 +785,6 @@ class HorizontalPodAutoscalerSpec(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta2", kind="HorizontalPodAutoscalerSpec"
         )
         self._properties = {
-            "behavior": behavior
-            if behavior is not None
-            else HorizontalPodAutoscalerBehavior(),
             "maxReplicas": max_replicas if max_replicas is not None else None,
             "metrics": metrics if metrics is not None else [],
             "minReplicas": min_replicas if min_replicas is not None else None,
@@ -1295,41 +793,12 @@ class HorizontalPodAutoscalerSpec(_kuber_definitions.Definition):
             else CrossVersionObjectReference(),
         }
         self._types = {
-            "behavior": (HorizontalPodAutoscalerBehavior, None),
             "maxReplicas": (int, None),
             "metrics": (list, MetricSpec),
             "minReplicas": (int, None),
             "scaleTargetRef": (CrossVersionObjectReference, None),
         }
 
-    @property
-    def behavior(self) -> "HorizontalPodAutoscalerBehavior":
-        """
-        behavior configures the scaling behavior of the target in
-        both Up and Down directions (scaleUp and scaleDown fields
-        respectively). If not set, the default HPAScalingRules for
-        scale up and scale down are used.
-        """
-        return typing.cast(
-            "HorizontalPodAutoscalerBehavior",
-            self._properties.get("behavior"),
-        )
-
-    @behavior.setter
-    def behavior(self, value: typing.Union["HorizontalPodAutoscalerBehavior", dict]):
-        """
-        behavior configures the scaling behavior of the target in
-        both Up and Down directions (scaleUp and scaleDown fields
-        respectively). If not set, the default HPAScalingRules for
-        scale up and scale down are used.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                HorizontalPodAutoscalerBehavior,
-                HorizontalPodAutoscalerBehavior().from_dict(value),
-            )
-        self._properties["behavior"] = value
-
     @property
     def max_replicas(self) -> int:
         """
@@ -1743,7 +1212,6 @@ class MetricSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        container_resource: "ContainerResourceMetricSource" = None,
         external: "ExternalMetricSource" = None,
         object_: "ObjectMetricSource" = None,
         pods: "PodsMetricSource" = None,
@@ -1755,9 +1223,6 @@ class MetricSpec(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta2", kind="MetricSpec"
         )
         self._properties = {
-            "containerResource": container_resource
-            if container_resource is not None
-            else ContainerResourceMetricSource(),
             "external": external if external is not None else ExternalMetricSource(),
             "object": object_ if object_ is not None else ObjectMetricSource(),
             "pods": pods if pods is not None else PodsMetricSource(),
@@ -1765,7 +1230,6 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
-            "containerResource": (ContainerResourceMetricSource, None),
             "external": (ExternalMetricSource, None),
             "object": (ObjectMetricSource, None),
             "pods": (PodsMetricSource, None),
@@ -1773,44 +1237,6 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
-    @property
-    def container_resource(self) -> "ContainerResourceMetricSource":
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod of the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source. This is an alpha feature and can be enabled by the
-        HPAContainerMetrics feature flag.
-        """
-        return typing.cast(
-            "ContainerResourceMetricSource",
-            self._properties.get("containerResource"),
-        )
-
-    @container_resource.setter
-    def container_resource(
-        self, value: typing.Union["ContainerResourceMetricSource", dict]
-    ):
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod of the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source. This is an alpha feature and can be enabled by the
-        HPAContainerMetrics feature flag.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                ContainerResourceMetricSource,
-                ContainerResourceMetricSource().from_dict(value),
-            )
-        self._properties["containerResource"] = value
-
     @property
     def external(self) -> "ExternalMetricSource":
         """
@@ -1931,10 +1357,8 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It should be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each mapping to a matching field in the object.
-        Note: "ContainerResource" type is available on when the
-        feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each mapping to a matching
+        field in the object.
         """
         return typing.cast(
             str,
@@ -1945,10 +1369,8 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It should be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each mapping to a matching field in the object.
-        Note: "ContainerResource" type is available on when the
-        feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each mapping to a matching
+        field in the object.
         """
         self._properties["type"] = value
 
@@ -1967,7 +1389,6 @@ class MetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        container_resource: "ContainerResourceMetricStatus" = None,
         external: "ExternalMetricStatus" = None,
         object_: "ObjectMetricStatus" = None,
         pods: "PodsMetricStatus" = None,
@@ -1979,9 +1400,6 @@ class MetricStatus(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta2", kind="MetricStatus"
         )
         self._properties = {
-            "containerResource": container_resource
-            if container_resource is not None
-            else ContainerResourceMetricStatus(),
             "external": external if external is not None else ExternalMetricStatus(),
             "object": object_ if object_ is not None else ObjectMetricStatus(),
             "pods": pods if pods is not None else PodsMetricStatus(),
@@ -1989,7 +1407,6 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
-            "containerResource": (ContainerResourceMetricStatus, None),
             "external": (ExternalMetricStatus, None),
             "object": (ObjectMetricStatus, None),
             "pods": (PodsMetricStatus, None),
@@ -1997,42 +1414,6 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
-    @property
-    def container_resource(self) -> "ContainerResourceMetricStatus":
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod in the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source.
-        """
-        return typing.cast(
-            "ContainerResourceMetricStatus",
-            self._properties.get("containerResource"),
-        )
-
-    @container_resource.setter
-    def container_resource(
-        self, value: typing.Union["ContainerResourceMetricStatus", dict]
-    ):
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod in the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                ContainerResourceMetricStatus,
-                ContainerResourceMetricStatus().from_dict(value),
-            )
-        self._properties["containerResource"] = value
-
     @property
     def external(self) -> "ExternalMetricStatus":
         """
@@ -2153,10 +1534,8 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It will be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each corresponds to a matching field in the
-        object. Note: "ContainerResource" type is available on when
-        the feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each corresponds to a
+        matching field in the object.
         """
         return typing.cast(
             str,
@@ -2167,10 +1546,8 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It will be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each corresponds to a matching field in the
-        object. Note: "ContainerResource" type is available on when
-        the feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each corresponds to a
+        matching field in the object.
         """
         self._properties["type"] = value
 
@@ -2208,9 +1585,9 @@ class MetricTarget(_kuber_definitions.Definition):
         }
         self._types = {
             "averageUtilization": (int, None),
-            "averageValue": (str, None),
+            "averageValue": (_types.integer_or_string, None),
             "type": (str, None),
-            "value": (str, None),
+            "value": (_types.integer_or_string, None),
         }
 
     @property
@@ -2251,7 +1628,7 @@ class MetricTarget(_kuber_definitions.Definition):
         averageValue is the target value of the average of the
         metric across all relevant pods (as a quantity)
         """
-        self._properties["averageValue"] = None if value is None else f"{value}"
+        self._properties["averageValue"] = _types.integer_or_string(value)
 
     @property
     def type_(self) -> str:
@@ -2285,7 +1662,7 @@ class MetricTarget(_kuber_definitions.Definition):
         """
         value is the target value of the metric (as a quantity).
         """
-        self._properties["value"] = None if value is None else f"{value}"
+        self._properties["value"] = _types.integer_or_string(value)
 
     def __enter__(self) -> "MetricTarget":
         return self
@@ -2318,8 +1695,8 @@ class MetricValueStatus(_kuber_definitions.Definition):
         }
         self._types = {
             "averageUtilization": (int, None),
-            "averageValue": (str, None),
-            "value": (str, None),
+            "averageValue": (_types.integer_or_string, None),
+            "value": (_types.integer_or_string, None),
         }
 
     @property
@@ -2360,7 +1737,7 @@ class MetricValueStatus(_kuber_definitions.Definition):
         averageValue is the current value of the average of the
         metric across all relevant pods (as a quantity)
         """
-        self._properties["averageValue"] = None if value is None else f"{value}"
+        self._properties["averageValue"] = _types.integer_or_string(value)
 
     @property
     def value(self) -> typing.Optional[str]:
@@ -2375,7 +1752,7 @@ class MetricValueStatus(_kuber_definitions.Definition):
         """
         value is the current value of the metric (as a quantity).
         """
-        self._properties["value"] = None if value is None else f"{value}"
+        self._properties["value"] = _types.integer_or_string(value)
 
     def __enter__(self) -> "MetricValueStatus":
         return self
