@@ -5,10 +5,11 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import Status  # noqa: F401
-from kuber.v1_20.meta_v1 import StatusDetails  # noqa: F401
+from kuber import _types  # noqa: F401
+from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_16.meta_v1 import Status  # noqa: F401
+from kuber.v1_16.meta_v1 import StatusDetails  # noqa: F401
 
 
 class CertificateSigningRequest(_kuber_definitions.Resource):
@@ -282,11 +283,9 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        last_transition_time: str = None,
         last_update_time: str = None,
         message: str = None,
         reason: str = None,
-        status: str = None,
         type_: str = None,
     ):
         """Create CertificateSigningRequestCondition instance."""
@@ -295,57 +294,20 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
             kind="CertificateSigningRequestCondition",
         )
         self._properties = {
-            "lastTransitionTime": last_transition_time
-            if last_transition_time is not None
-            else None,
             "lastUpdateTime": last_update_time
             if last_update_time is not None
             else None,
             "message": message if message is not None else "",
             "reason": reason if reason is not None else "",
-            "status": status if status is not None else "",
             "type": type_ if type_ is not None else "",
         }
         self._types = {
-            "lastTransitionTime": (str, None),
             "lastUpdateTime": (str, None),
             "message": (str, None),
             "reason": (str, None),
-            "status": (str, None),
             "type": (str, None),
         }
 
-    @property
-    def last_transition_time(self) -> str:
-        """
-        lastTransitionTime is the time the condition last
-        transitioned from one status to another. If unset, when a
-        new condition type is added or an existing condition's
-        status is changed, the server defaults this to the current
-        time.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("lastTransitionTime"),
-        )
-
-    @last_transition_time.setter
-    def last_transition_time(
-        self, value: typing.Union[str, _datetime.datetime, _datetime.date]
-    ):
-        """
-        lastTransitionTime is the time the condition last
-        transitioned from one status to another. If unset, when a
-        new condition type is added or an existing condition's
-        status is changed, the server defaults this to the current
-        time.
-        """
-        if isinstance(value, _datetime.datetime):
-            value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
-        elif isinstance(value, _datetime.date):
-            value = value.strftime("%Y-%m-%dT00:00:00Z")
-        self._properties["lastTransitionTime"] = value
-
     @property
     def last_update_time(self) -> str:
         """
@@ -403,34 +365,10 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
         """
         self._properties["reason"] = value
 
-    @property
-    def status(self) -> str:
-        """
-        Status of the condition, one of True, False, Unknown.
-        Approved, Denied, and Failed conditions may not be "False"
-        or "Unknown". Defaults to "True". If unset, should be
-        treated as "True".
-        """
-        return typing.cast(
-            str,
-            self._properties.get("status"),
-        )
-
-    @status.setter
-    def status(self, value: str):
-        """
-        Status of the condition, one of True, False, Unknown.
-        Approved, Denied, and Failed conditions may not be "False"
-        or "Unknown". Defaults to "True". If unset, should be
-        treated as "True".
-        """
-        self._properties["status"] = value
-
     @property
     def type_(self) -> str:
         """
-        type of the condition. Known conditions include "Approved",
-        "Denied", and "Failed".
+        request approval state, currently Approved or Denied.
         """
         return typing.cast(
             str,
@@ -440,8 +378,7 @@ class CertificateSigningRequestCondition(_kuber_definitions.Definition):
     @type_.setter
     def type_(self, value: str):
         """
-        type of the condition. Known conditions include "Approved",
-        "Denied", and "Failed".
+        request approval state, currently Approved or Denied.
         """
         self._properties["type"] = value
 
@@ -551,7 +488,6 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         extra: dict = None,
         groups: typing.List[str] = None,
         request: str = None,
-        signer_name: str = None,
         uid: str = None,
         usages: typing.List[str] = None,
         username: str = None,
@@ -564,7 +500,6 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
             "extra": extra if extra is not None else {},
             "groups": groups if groups is not None else [],
             "request": request if request is not None else "",
-            "signerName": signer_name if signer_name is not None else "",
             "uid": uid if uid is not None else "",
             "usages": usages if usages is not None else [],
             "username": username if username is not None else "",
@@ -573,7 +508,6 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
             "extra": (dict, None),
             "groups": (list, str),
             "request": (str, None),
-            "signerName": (str, None),
             "uid": (str, None),
             "usages": (list, str),
             "username": (str, None),
@@ -634,43 +568,6 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         """
         self._properties["request"] = value
 
-    @property
-    def signer_name(self) -> str:
-        """
-        Requested signer for the request. It is a qualified name in
-        the form: `scope-hostname.io/name`. If empty, it will be
-        defaulted:
-         1. If it's a kubelet client certificate, it is assigned
-            "kubernetes.io/kube-apiserver-client-kubelet".
-         2. If it's a kubelet serving certificate, it is assigned
-            "kubernetes.io/kubelet-serving".
-         3. Otherwise, it is assigned "kubernetes.io/legacy-
-        unknown".
-        Distribution of trust for signers happens out of band. You
-        can select on this field using `spec.signerName`.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("signerName"),
-        )
-
-    @signer_name.setter
-    def signer_name(self, value: str):
-        """
-        Requested signer for the request. It is a qualified name in
-        the form: `scope-hostname.io/name`. If empty, it will be
-        defaulted:
-         1. If it's a kubelet client certificate, it is assigned
-            "kubernetes.io/kube-apiserver-client-kubelet".
-         2. If it's a kubelet serving certificate, it is assigned
-            "kubernetes.io/kubelet-serving".
-         3. Otherwise, it is assigned "kubernetes.io/legacy-
-        unknown".
-        Distribution of trust for signers happens out of band. You
-        can select on this field using `spec.signerName`.
-        """
-        self._properties["signerName"] = value
-
     @property
     def uid(self) -> str:
         """
@@ -697,30 +594,6 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         be valid for. See:
         https://tools.ietf.org/html/rfc5280#section-4.2.1.3
              https://tools.ietf.org/html/rfc5280#section-4.2.1.12
-        Valid values are:
-         "signing",
-         "digital signature",
-         "content commitment",
-         "key encipherment",
-         "key agreement",
-         "data encipherment",
-         "cert sign",
-         "crl sign",
-         "encipher only",
-         "decipher only",
-         "any",
-         "server auth",
-         "client auth",
-         "code signing",
-         "email protection",
-         "s/mime",
-         "ipsec end system",
-         "ipsec tunnel",
-         "ipsec user",
-         "timestamping",
-         "ocsp signing",
-         "microsoft sgc",
-         "netscape sgc"
         """
         return typing.cast(
             typing.List[str],
@@ -734,30 +607,6 @@ class CertificateSigningRequestSpec(_kuber_definitions.Definition):
         be valid for. See:
         https://tools.ietf.org/html/rfc5280#section-4.2.1.3
              https://tools.ietf.org/html/rfc5280#section-4.2.1.12
-        Valid values are:
-         "signing",
-         "digital signature",
-         "content commitment",
-         "key encipherment",
-         "key agreement",
-         "data encipherment",
-         "cert sign",
-         "crl sign",
-         "encipher only",
-         "decipher only",
-         "any",
-         "server auth",
-         "client auth",
-         "code signing",
-         "email protection",
-         "s/mime",
-         "ipsec end system",
-         "ipsec tunnel",
-         "ipsec user",
-         "timestamping",
-         "ocsp signing",
-         "microsoft sgc",
-         "netscape sgc"
         """
         self._properties["usages"] = value
 
