@@ -5,271 +5,12 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_20.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import Status  # noqa: F401
-from kuber.v1_20.meta_v1 import StatusDetails  # noqa: F401
-
-
-class ContainerResourceMetricSource(_kuber_definitions.Definition):
-    """
-    ContainerResourceMetricSource indicates how to scale on a
-    resource metric known to Kubernetes, as specified in
-    requests and limits, describing each pod in the current
-    scale target (e.g. CPU or memory).  The values will be
-    averaged together before being compared to the target.  Such
-    metrics are built in to Kubernetes, and have special scaling
-    options on top of those available to normal per-pod metrics
-    using the "pods" source.  Only one "target" type should be
-    set.
-    """
-
-    def __init__(
-        self,
-        container: str = None,
-        name: str = None,
-        target_average_utilization: int = None,
-        target_average_value: typing.Union[str, int, None] = None,
-    ):
-        """Create ContainerResourceMetricSource instance."""
-        super(ContainerResourceMetricSource, self).__init__(
-            api_version="autoscaling/v2beta1", kind="ContainerResourceMetricSource"
-        )
-        self._properties = {
-            "container": container if container is not None else "",
-            "name": name if name is not None else "",
-            "targetAverageUtilization": target_average_utilization
-            if target_average_utilization is not None
-            else None,
-            "targetAverageValue": target_average_value
-            if target_average_value is not None
-            else None,
-        }
-        self._types = {
-            "container": (str, None),
-            "name": (str, None),
-            "targetAverageUtilization": (int, None),
-            "targetAverageValue": (str, None),
-        }
-
-    @property
-    def container(self) -> str:
-        """
-        container is the name of the container in the pods of the
-        scaling target
-        """
-        return typing.cast(
-            str,
-            self._properties.get("container"),
-        )
-
-    @container.setter
-    def container(self, value: str):
-        """
-        container is the name of the container in the pods of the
-        scaling target
-        """
-        self._properties["container"] = value
-
-    @property
-    def name(self) -> str:
-        """
-        name is the name of the resource in question.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("name"),
-        )
-
-    @name.setter
-    def name(self, value: str):
-        """
-        name is the name of the resource in question.
-        """
-        self._properties["name"] = value
-
-    @property
-    def target_average_utilization(self) -> int:
-        """
-        targetAverageUtilization is the target value of the average
-        of the resource metric across all relevant pods, represented
-        as a percentage of the requested value of the resource for
-        the pods.
-        """
-        return typing.cast(
-            int,
-            self._properties.get("targetAverageUtilization"),
-        )
-
-    @target_average_utilization.setter
-    def target_average_utilization(self, value: int):
-        """
-        targetAverageUtilization is the target value of the average
-        of the resource metric across all relevant pods, represented
-        as a percentage of the requested value of the resource for
-        the pods.
-        """
-        self._properties["targetAverageUtilization"] = value
-
-    @property
-    def target_average_value(self) -> typing.Optional[str]:
-        """
-        targetAverageValue is the target value of the average of the
-        resource metric across all relevant pods, as a raw value
-        (instead of as a percentage of the request), similar to the
-        "pods" metric source type.
-        """
-        value = self._properties.get("targetAverageValue")
-        return f"{value}" if value is not None else None
-
-    @target_average_value.setter
-    def target_average_value(self, value: typing.Union[str, int, None]):
-        """
-        targetAverageValue is the target value of the average of the
-        resource metric across all relevant pods, as a raw value
-        (instead of as a percentage of the request), similar to the
-        "pods" metric source type.
-        """
-        self._properties["targetAverageValue"] = None if value is None else f"{value}"
-
-    def __enter__(self) -> "ContainerResourceMetricSource":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
-
-
-class ContainerResourceMetricStatus(_kuber_definitions.Definition):
-    """
-    ContainerResourceMetricStatus indicates the current value of
-    a resource metric known to Kubernetes, as specified in
-    requests and limits, describing a single container in each
-    pod in the current scale target (e.g. CPU or memory).  Such
-    metrics are built in to Kubernetes, and have special scaling
-    options on top of those available to normal per-pod metrics
-    using the "pods" source.
-    """
-
-    def __init__(
-        self,
-        container: str = None,
-        current_average_utilization: int = None,
-        current_average_value: typing.Union[str, int, None] = None,
-        name: str = None,
-    ):
-        """Create ContainerResourceMetricStatus instance."""
-        super(ContainerResourceMetricStatus, self).__init__(
-            api_version="autoscaling/v2beta1", kind="ContainerResourceMetricStatus"
-        )
-        self._properties = {
-            "container": container if container is not None else "",
-            "currentAverageUtilization": current_average_utilization
-            if current_average_utilization is not None
-            else None,
-            "currentAverageValue": current_average_value
-            if current_average_value is not None
-            else None,
-            "name": name if name is not None else "",
-        }
-        self._types = {
-            "container": (str, None),
-            "currentAverageUtilization": (int, None),
-            "currentAverageValue": (str, None),
-            "name": (str, None),
-        }
-
-    @property
-    def container(self) -> str:
-        """
-        container is the name of the container in the pods of the
-        scaling target
-        """
-        return typing.cast(
-            str,
-            self._properties.get("container"),
-        )
-
-    @container.setter
-    def container(self, value: str):
-        """
-        container is the name of the container in the pods of the
-        scaling target
-        """
-        self._properties["container"] = value
-
-    @property
-    def current_average_utilization(self) -> int:
-        """
-        currentAverageUtilization is the current value of the
-        average of the resource metric across all relevant pods,
-        represented as a percentage of the requested value of the
-        resource for the pods.  It will only be present if
-        `targetAverageValue` was set in the corresponding metric
-        specification.
-        """
-        return typing.cast(
-            int,
-            self._properties.get("currentAverageUtilization"),
-        )
-
-    @current_average_utilization.setter
-    def current_average_utilization(self, value: int):
-        """
-        currentAverageUtilization is the current value of the
-        average of the resource metric across all relevant pods,
-        represented as a percentage of the requested value of the
-        resource for the pods.  It will only be present if
-        `targetAverageValue` was set in the corresponding metric
-        specification.
-        """
-        self._properties["currentAverageUtilization"] = value
-
-    @property
-    def current_average_value(self) -> typing.Optional[str]:
-        """
-        currentAverageValue is the current value of the average of
-        the resource metric across all relevant pods, as a raw value
-        (instead of as a percentage of the request), similar to the
-        "pods" metric source type. It will always be set, regardless
-        of the corresponding metric specification.
-        """
-        value = self._properties.get("currentAverageValue")
-        return f"{value}" if value is not None else None
-
-    @current_average_value.setter
-    def current_average_value(self, value: typing.Union[str, int, None]):
-        """
-        currentAverageValue is the current value of the average of
-        the resource metric across all relevant pods, as a raw value
-        (instead of as a percentage of the request), similar to the
-        "pods" metric source type. It will always be set, regardless
-        of the corresponding metric specification.
-        """
-        self._properties["currentAverageValue"] = None if value is None else f"{value}"
-
-    @property
-    def name(self) -> str:
-        """
-        name is the name of the resource in question.
-        """
-        return typing.cast(
-            str,
-            self._properties.get("name"),
-        )
-
-    @name.setter
-    def name(self, value: str):
-        """
-        name is the name of the resource in question.
-        """
-        self._properties["name"] = value
-
-    def __enter__(self) -> "ContainerResourceMetricStatus":
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        return False
+from kuber import _types  # noqa: F401
+from kuber.v1_17.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_17.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_17.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_17.meta_v1 import Status  # noqa: F401
+from kuber.v1_17.meta_v1 import StatusDetails  # noqa: F401
 
 
 class CrossVersionObjectReference(_kuber_definitions.Definition):
@@ -396,8 +137,8 @@ class ExternalMetricSource(_kuber_definitions.Definition):
         self._types = {
             "metricName": (str, None),
             "metricSelector": (LabelSelector, None),
-            "targetAverageValue": (str, None),
-            "targetValue": (str, None),
+            "targetAverageValue": (_types.integer_or_string, None),
+            "targetValue": (_types.integer_or_string, None),
         }
 
     @property
@@ -456,7 +197,7 @@ class ExternalMetricSource(_kuber_definitions.Definition):
         targetAverageValue is the target per-pod value of global
         metric (as a quantity). Mutually exclusive with TargetValue.
         """
-        self._properties["targetAverageValue"] = None if value is None else f"{value}"
+        self._properties["targetAverageValue"] = _types.integer_or_string(value)
 
     @property
     def target_value(self) -> typing.Optional[str]:
@@ -473,7 +214,7 @@ class ExternalMetricSource(_kuber_definitions.Definition):
         targetValue is the target value of the metric (as a
         quantity). Mutually exclusive with TargetAverageValue.
         """
-        self._properties["targetValue"] = None if value is None else f"{value}"
+        self._properties["targetValue"] = _types.integer_or_string(value)
 
     def __enter__(self) -> "ExternalMetricSource":
         return self
@@ -510,8 +251,8 @@ class ExternalMetricStatus(_kuber_definitions.Definition):
             else LabelSelector(),
         }
         self._types = {
-            "currentAverageValue": (str, None),
-            "currentValue": (str, None),
+            "currentAverageValue": (_types.integer_or_string, None),
+            "currentValue": (_types.integer_or_string, None),
             "metricName": (str, None),
             "metricSelector": (LabelSelector, None),
         }
@@ -531,7 +272,7 @@ class ExternalMetricStatus(_kuber_definitions.Definition):
         currentAverageValue is the current value of metric averaged
         over autoscaled pods.
         """
-        self._properties["currentAverageValue"] = None if value is None else f"{value}"
+        self._properties["currentAverageValue"] = _types.integer_or_string(value)
 
     @property
     def current_value(self) -> typing.Optional[str]:
@@ -548,7 +289,7 @@ class ExternalMetricStatus(_kuber_definitions.Definition):
         currentValue is the current value of the metric (as a
         quantity)
         """
-        self._properties["currentValue"] = None if value is None else f"{value}"
+        self._properties["currentValue"] = _types.integer_or_string(value)
 
     @property
     def metric_name(self) -> str:
@@ -1476,7 +1217,6 @@ class MetricSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        container_resource: "ContainerResourceMetricSource" = None,
         external: "ExternalMetricSource" = None,
         object_: "ObjectMetricSource" = None,
         pods: "PodsMetricSource" = None,
@@ -1488,9 +1228,6 @@ class MetricSpec(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta1", kind="MetricSpec"
         )
         self._properties = {
-            "containerResource": container_resource
-            if container_resource is not None
-            else ContainerResourceMetricSource(),
             "external": external if external is not None else ExternalMetricSource(),
             "object": object_ if object_ is not None else ObjectMetricSource(),
             "pods": pods if pods is not None else PodsMetricSource(),
@@ -1498,7 +1235,6 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
-            "containerResource": (ContainerResourceMetricSource, None),
             "external": (ExternalMetricSource, None),
             "object": (ObjectMetricSource, None),
             "pods": (PodsMetricSource, None),
@@ -1506,44 +1242,6 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
-    @property
-    def container_resource(self) -> "ContainerResourceMetricSource":
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod of the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source. This is an alpha feature and can be enabled by the
-        HPAContainerMetrics feature flag.
-        """
-        return typing.cast(
-            "ContainerResourceMetricSource",
-            self._properties.get("containerResource"),
-        )
-
-    @container_resource.setter
-    def container_resource(
-        self, value: typing.Union["ContainerResourceMetricSource", dict]
-    ):
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod of the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source. This is an alpha feature and can be enabled by the
-        HPAContainerMetrics feature flag.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                ContainerResourceMetricSource,
-                ContainerResourceMetricSource().from_dict(value),
-            )
-        self._properties["containerResource"] = value
-
     @property
     def external(self) -> "ExternalMetricSource":
         """
@@ -1664,10 +1362,8 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It should be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each mapping to a matching field in the object.
-        Note: "ContainerResource" type is available on when the
-        feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each mapping to a matching
+        field in the object.
         """
         return typing.cast(
             str,
@@ -1678,10 +1374,8 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It should be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each mapping to a matching field in the object.
-        Note: "ContainerResource" type is available on when the
-        feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each mapping to a matching
+        field in the object.
         """
         self._properties["type"] = value
 
@@ -1700,7 +1394,6 @@ class MetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        container_resource: "ContainerResourceMetricStatus" = None,
         external: "ExternalMetricStatus" = None,
         object_: "ObjectMetricStatus" = None,
         pods: "PodsMetricStatus" = None,
@@ -1712,9 +1405,6 @@ class MetricStatus(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta1", kind="MetricStatus"
         )
         self._properties = {
-            "containerResource": container_resource
-            if container_resource is not None
-            else ContainerResourceMetricStatus(),
             "external": external if external is not None else ExternalMetricStatus(),
             "object": object_ if object_ is not None else ObjectMetricStatus(),
             "pods": pods if pods is not None else PodsMetricStatus(),
@@ -1722,7 +1412,6 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
-            "containerResource": (ContainerResourceMetricStatus, None),
             "external": (ExternalMetricStatus, None),
             "object": (ObjectMetricStatus, None),
             "pods": (PodsMetricStatus, None),
@@ -1730,42 +1419,6 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
-    @property
-    def container_resource(self) -> "ContainerResourceMetricStatus":
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod in the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source.
-        """
-        return typing.cast(
-            "ContainerResourceMetricStatus",
-            self._properties.get("containerResource"),
-        )
-
-    @container_resource.setter
-    def container_resource(
-        self, value: typing.Union["ContainerResourceMetricStatus", dict]
-    ):
-        """
-        container resource refers to a resource metric (such as
-        those specified in requests and limits) known to Kubernetes
-        describing a single container in each pod in the current
-        scale target (e.g. CPU or memory). Such metrics are built in
-        to Kubernetes, and have special scaling options on top of
-        those available to normal per-pod metrics using the "pods"
-        source.
-        """
-        if isinstance(value, dict):
-            value = typing.cast(
-                ContainerResourceMetricStatus,
-                ContainerResourceMetricStatus().from_dict(value),
-            )
-        self._properties["containerResource"] = value
-
     @property
     def external(self) -> "ExternalMetricStatus":
         """
@@ -1886,10 +1539,8 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It will be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each corresponds to a matching field in the
-        object. Note: "ContainerResource" type is available on when
-        the feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each corresponds to a
+        matching field in the object.
         """
         return typing.cast(
             str,
@@ -1900,10 +1551,8 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It will be one of
-        "ContainerResource", "External", "Object", "Pods" or
-        "Resource", each corresponds to a matching field in the
-        object. Note: "ContainerResource" type is available on when
-        the feature-gate HPAContainerMetrics is enabled
+        "Object", "Pods" or "Resource", each corresponds to a
+        matching field in the object.
         """
         self._properties["type"] = value
 
@@ -1941,11 +1590,11 @@ class ObjectMetricSource(_kuber_definitions.Definition):
             "targetValue": target_value if target_value is not None else None,
         }
         self._types = {
-            "averageValue": (str, None),
+            "averageValue": (_types.integer_or_string, None),
             "metricName": (str, None),
             "selector": (LabelSelector, None),
             "target": (CrossVersionObjectReference, None),
-            "targetValue": (str, None),
+            "targetValue": (_types.integer_or_string, None),
         }
 
     @property
@@ -1963,7 +1612,7 @@ class ObjectMetricSource(_kuber_definitions.Definition):
         averageValue is the target value of the average of the
         metric across all relevant pods (as a quantity)
         """
-        self._properties["averageValue"] = None if value is None else f"{value}"
+        self._properties["averageValue"] = _types.integer_or_string(value)
 
     @property
     def metric_name(self) -> str:
@@ -2049,7 +1698,7 @@ class ObjectMetricSource(_kuber_definitions.Definition):
         targetValue is the target value of the metric (as a
         quantity).
         """
-        self._properties["targetValue"] = None if value is None else f"{value}"
+        self._properties["targetValue"] = _types.integer_or_string(value)
 
     def __enter__(self) -> "ObjectMetricSource":
         return self
@@ -2085,8 +1734,8 @@ class ObjectMetricStatus(_kuber_definitions.Definition):
             "target": target if target is not None else CrossVersionObjectReference(),
         }
         self._types = {
-            "averageValue": (str, None),
-            "currentValue": (str, None),
+            "averageValue": (_types.integer_or_string, None),
+            "currentValue": (_types.integer_or_string, None),
             "metricName": (str, None),
             "selector": (LabelSelector, None),
             "target": (CrossVersionObjectReference, None),
@@ -2107,7 +1756,7 @@ class ObjectMetricStatus(_kuber_definitions.Definition):
         averageValue is the current value of the average of the
         metric across all relevant pods (as a quantity)
         """
-        self._properties["averageValue"] = None if value is None else f"{value}"
+        self._properties["averageValue"] = _types.integer_or_string(value)
 
     @property
     def current_value(self) -> typing.Optional[str]:
@@ -2124,7 +1773,7 @@ class ObjectMetricStatus(_kuber_definitions.Definition):
         currentValue is the current value of the metric (as a
         quantity).
         """
-        self._properties["currentValue"] = None if value is None else f"{value}"
+        self._properties["currentValue"] = _types.integer_or_string(value)
 
     @property
     def metric_name(self) -> str:
@@ -2233,7 +1882,7 @@ class PodsMetricSource(_kuber_definitions.Definition):
         self._types = {
             "metricName": (str, None),
             "selector": (LabelSelector, None),
-            "targetAverageValue": (str, None),
+            "targetAverageValue": (_types.integer_or_string, None),
         }
 
     @property
@@ -2298,7 +1947,7 @@ class PodsMetricSource(_kuber_definitions.Definition):
         targetAverageValue is the target value of the average of the
         metric across all relevant pods (as a quantity)
         """
-        self._properties["targetAverageValue"] = None if value is None else f"{value}"
+        self._properties["targetAverageValue"] = _types.integer_or_string(value)
 
     def __enter__(self) -> "PodsMetricSource":
         return self
@@ -2332,7 +1981,7 @@ class PodsMetricStatus(_kuber_definitions.Definition):
             "selector": selector if selector is not None else LabelSelector(),
         }
         self._types = {
-            "currentAverageValue": (str, None),
+            "currentAverageValue": (_types.integer_or_string, None),
             "metricName": (str, None),
             "selector": (LabelSelector, None),
         }
@@ -2352,7 +2001,7 @@ class PodsMetricStatus(_kuber_definitions.Definition):
         currentAverageValue is the current value of the average of
         the metric across all relevant pods (as a quantity)
         """
-        self._properties["currentAverageValue"] = None if value is None else f"{value}"
+        self._properties["currentAverageValue"] = _types.integer_or_string(value)
 
     @property
     def metric_name(self) -> str:
@@ -2442,7 +2091,7 @@ class ResourceMetricSource(_kuber_definitions.Definition):
         self._types = {
             "name": (str, None),
             "targetAverageUtilization": (int, None),
-            "targetAverageValue": (str, None),
+            "targetAverageValue": (_types.integer_or_string, None),
         }
 
     @property
@@ -2504,7 +2153,7 @@ class ResourceMetricSource(_kuber_definitions.Definition):
         (instead of as a percentage of the request), similar to the
         "pods" metric source type.
         """
-        self._properties["targetAverageValue"] = None if value is None else f"{value}"
+        self._properties["targetAverageValue"] = _types.integer_or_string(value)
 
     def __enter__(self) -> "ResourceMetricSource":
         return self
@@ -2545,7 +2194,7 @@ class ResourceMetricStatus(_kuber_definitions.Definition):
         }
         self._types = {
             "currentAverageUtilization": (int, None),
-            "currentAverageValue": (str, None),
+            "currentAverageValue": (_types.integer_or_string, None),
             "name": (str, None),
         }
 
@@ -2597,7 +2246,7 @@ class ResourceMetricStatus(_kuber_definitions.Definition):
         "pods" metric source type. It will always be set, regardless
         of the corresponding metric specification.
         """
-        self._properties["currentAverageValue"] = None if value is None else f"{value}"
+        self._properties["currentAverageValue"] = _types.integer_or_string(value)
 
     @property
     def name(self) -> str:
