@@ -5,22 +5,23 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_15.core_v1 import Container  # noqa: F401
-from kuber.v1_15.core_v1 import ContainerPort  # noqa: F401
-from kuber.v1_15.core_v1 import EnvFromSource  # noqa: F401
-from kuber.v1_15.core_v1 import EnvVar  # noqa: F401
-from kuber.v1_15.batch_v1 import JobSpec  # noqa: F401
-from kuber.v1_15.core_v1 import Lifecycle  # noqa: F401
-from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_15.core_v1 import ObjectReference  # noqa: F401
-from kuber.v1_15.core_v1 import Probe  # noqa: F401
-from kuber.v1_15.core_v1 import ResourceRequirements  # noqa: F401
-from kuber.v1_15.core_v1 import SecurityContext  # noqa: F401
-from kuber.v1_15.meta_v1 import Status  # noqa: F401
-from kuber.v1_15.meta_v1 import StatusDetails  # noqa: F401
-from kuber.v1_15.core_v1 import VolumeDevice  # noqa: F401
-from kuber.v1_15.core_v1 import VolumeMount  # noqa: F401
+from kuber import _types  # noqa: F401
+from kuber.v1_17.core_v1 import Container  # noqa: F401
+from kuber.v1_17.core_v1 import ContainerPort  # noqa: F401
+from kuber.v1_17.core_v1 import EnvFromSource  # noqa: F401
+from kuber.v1_17.core_v1 import EnvVar  # noqa: F401
+from kuber.v1_17.batch_v1 import JobSpec  # noqa: F401
+from kuber.v1_17.core_v1 import Lifecycle  # noqa: F401
+from kuber.v1_17.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_17.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_17.core_v1 import ObjectReference  # noqa: F401
+from kuber.v1_17.core_v1 import Probe  # noqa: F401
+from kuber.v1_17.core_v1 import ResourceRequirements  # noqa: F401
+from kuber.v1_17.core_v1 import SecurityContext  # noqa: F401
+from kuber.v1_17.meta_v1 import Status  # noqa: F401
+from kuber.v1_17.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_17.core_v1 import VolumeDevice  # noqa: F401
+from kuber.v1_17.core_v1 import VolumeMount  # noqa: F401
 
 
 class CronJob(_kuber_definitions.Resource):
@@ -53,8 +54,8 @@ class CronJob(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -65,8 +66,8 @@ class CronJob(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -80,8 +81,8 @@ class CronJob(_kuber_definitions.Resource):
         """
         Specification of the desired behavior of a cron job,
         including the schedule. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "CronJobSpec",
@@ -93,8 +94,8 @@ class CronJob(_kuber_definitions.Resource):
         """
         Specification of the desired behavior of a cron job,
         including the schedule. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -107,8 +108,8 @@ class CronJob(_kuber_definitions.Resource):
     def status(self) -> "CronJobStatus":
         """
         Current status of a cron job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "CronJobStatus",
@@ -119,8 +120,8 @@ class CronJob(_kuber_definitions.Resource):
     def status(self, value: typing.Union["CronJobStatus", dict]):
         """
         Current status of a cron job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -183,6 +184,10 @@ class CronJob(_kuber_definitions.Resource):
             "SecurityContext",
             _kuber_definitions.InternalValue,
         ] = _kuber_definitions.UNCHANGED_VALUE,
+        startup_probe: typing.Union[
+            "Probe",
+            _kuber_definitions.InternalValue,
+        ] = _kuber_definitions.UNCHANGED_VALUE,
         stdin: typing.Union[
             bool,
             _kuber_definitions.InternalValue,
@@ -231,6 +236,7 @@ class CronJob(_kuber_definitions.Resource):
             "readiness_probe": readiness_probe,
             "resources": resources,
             "security_context": security_context,
+            "startup_probe": startup_probe,
             "stdin": stdin,
             "stdin_once": stdin_once,
             "termination_message_path": termination_message_path,
@@ -482,8 +488,8 @@ class CronJobList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -494,8 +500,8 @@ class CronJobList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -778,6 +784,10 @@ class CronJobSpec(_kuber_definitions.Definition):
             "SecurityContext",
             _kuber_definitions.InternalValue,
         ] = _kuber_definitions.UNCHANGED_VALUE,
+        startup_probe: typing.Union[
+            "Probe",
+            _kuber_definitions.InternalValue,
+        ] = _kuber_definitions.UNCHANGED_VALUE,
         stdin: typing.Union[
             bool,
             _kuber_definitions.InternalValue,
@@ -826,6 +836,7 @@ class CronJobSpec(_kuber_definitions.Definition):
             "readiness_probe": readiness_probe,
             "resources": resources,
             "security_context": security_context,
+            "startup_probe": startup_probe,
             "stdin": stdin,
             "stdin_once": stdin_once,
             "termination_message_path": termination_message_path,
@@ -988,8 +999,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         """
         Standard object's metadata of the jobs created from this
         template. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -1001,8 +1012,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         """
         Standard object's metadata of the jobs created from this
         template. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1015,8 +1026,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
     def spec(self) -> "JobSpec":
         """
         Specification of the desired behavior of the job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "JobSpec",
@@ -1027,8 +1038,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
     def spec(self, value: typing.Union["JobSpec", dict]):
         """
         Specification of the desired behavior of the job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1091,6 +1102,10 @@ class JobTemplateSpec(_kuber_definitions.Definition):
             "SecurityContext",
             _kuber_definitions.InternalValue,
         ] = _kuber_definitions.UNCHANGED_VALUE,
+        startup_probe: typing.Union[
+            "Probe",
+            _kuber_definitions.InternalValue,
+        ] = _kuber_definitions.UNCHANGED_VALUE,
         stdin: typing.Union[
             bool,
             _kuber_definitions.InternalValue,
@@ -1139,6 +1154,7 @@ class JobTemplateSpec(_kuber_definitions.Definition):
             "readiness_probe": readiness_probe,
             "resources": resources,
             "security_context": security_context,
+            "startup_probe": startup_probe,
             "stdin": stdin,
             "stdin_once": stdin_once,
             "termination_message_path": termination_message_path,
