@@ -4,13 +4,14 @@ from kubernetes import client  # noqa: F401
 from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
-from kuber.v1_17.meta_v1 import DeleteOptions  # noqa: F401
-from kuber.v1_17.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_17.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_17.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_17.core_v1 import SELinuxOptions  # noqa: F401
-from kuber.v1_17.meta_v1 import Status  # noqa: F401
-from kuber.v1_17.meta_v1 import StatusDetails  # noqa: F401
+from kuber import _types  # noqa: F401
+from kuber.v1_19.meta_v1 import DeleteOptions  # noqa: F401
+from kuber.v1_19.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_19.core_v1 import SELinuxOptions  # noqa: F401
+from kuber.v1_19.meta_v1 import Status  # noqa: F401
+from kuber.v1_19.meta_v1 import StatusDetails  # noqa: F401
 
 
 class AllowedCSIDriver(_kuber_definitions.Definition):
@@ -945,13 +946,13 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
             "selector": selector if selector is not None else LabelSelector(),
         }
         self._types = {
-            "maxUnavailable": (int, None),
-            "minAvailable": (int, None),
+            "maxUnavailable": (_types.integer_or_string, None),
+            "minAvailable": (_types.integer_or_string, None),
             "selector": (LabelSelector, None),
         }
 
     @property
-    def max_unavailable(self) -> typing.Optional[int]:
+    def max_unavailable(self) -> typing.Union[str, int, None]:
         """
         An eviction is allowed if at most "maxUnavailable" pods
         selected by "selector" are unavailable after the eviction,
@@ -959,8 +960,10 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
         can prevent all voluntary evictions by specifying 0. This is
         a mutually exclusive setting with "minAvailable".
         """
-        value = self._properties.get("maxUnavailable")
-        return int(value) if value is not None else None
+        return typing.cast(
+            typing.Union[str, int, None],
+            self._properties.get("maxUnavailable"),
+        )
 
     @max_unavailable.setter
     def max_unavailable(self, value: typing.Union[str, int, None]):
@@ -971,10 +974,10 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
         can prevent all voluntary evictions by specifying 0. This is
         a mutually exclusive setting with "minAvailable".
         """
-        self._properties["maxUnavailable"] = None if value is None else f"{value}"
+        self._properties["maxUnavailable"] = _types.integer_or_string(value)
 
     @property
-    def min_available(self) -> typing.Optional[int]:
+    def min_available(self) -> typing.Union[str, int, None]:
         """
         An eviction is allowed if at least "minAvailable" pods
         selected by "selector" will still be available after the
@@ -982,8 +985,10 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
         for example you can prevent all voluntary evictions by
         specifying "100%".
         """
-        value = self._properties.get("minAvailable")
-        return int(value) if value is not None else None
+        return typing.cast(
+            typing.Union[str, int, None],
+            self._properties.get("minAvailable"),
+        )
 
     @min_available.setter
     def min_available(self, value: typing.Union[str, int, None]):
@@ -994,7 +999,7 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
         for example you can prevent all voluntary evictions by
         specifying "100%".
         """
-        self._properties["minAvailable"] = None if value is None else f"{value}"
+        self._properties["minAvailable"] = _types.integer_or_string(value)
 
     @property
     def selector(self) -> "LabelSelector":
@@ -1185,8 +1190,8 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
     def observed_generation(self) -> int:
         """
         Most recent generation observed when updating this PDB
-        status. PodDisruptionsAllowed and other status information
-        is valid only if observedGeneration equals to PDB's object
+        status. DisruptionsAllowed and other status information is
+        valid only if observedGeneration equals to PDB's object
         generation.
         """
         return typing.cast(
@@ -1198,8 +1203,8 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
     def observed_generation(self, value: int):
         """
         Most recent generation observed when updating this PDB
-        status. PodDisruptionsAllowed and other status information
-        is valid only if observedGeneration equals to PDB's object
+        status. DisruptionsAllowed and other status information is
+        valid only if observedGeneration equals to PDB's object
         generation.
         """
         self._properties["observedGeneration"] = value
@@ -1650,11 +1655,11 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @property
     def allowed_csidrivers(self) -> typing.List["AllowedCSIDriver"]:
         """
-        AllowedCSIDrivers is a whitelist of inline CSI drivers that
+        AllowedCSIDrivers is an allowlist of inline CSI drivers that
         must be explicitly set to be embedded within a pod spec. An
         empty value indicates that any CSI driver can be used for
-        inline ephemeral volumes. This is an alpha field, and is
-        only honored if the API server enables the CSIInlineVolume
+        inline ephemeral volumes. This is a beta field, and is only
+        honored if the API server enables the CSIInlineVolume
         feature gate.
         """
         return typing.cast(
@@ -1667,11 +1672,11 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
         self, value: typing.Union[typing.List["AllowedCSIDriver"], typing.List[dict]]
     ):
         """
-        AllowedCSIDrivers is a whitelist of inline CSI drivers that
+        AllowedCSIDrivers is an allowlist of inline CSI drivers that
         must be explicitly set to be embedded within a pod spec. An
         empty value indicates that any CSI driver can be used for
-        inline ephemeral volumes. This is an alpha field, and is
-        only honored if the API server enables the CSIInlineVolume
+        inline ephemeral volumes. This is a beta field, and is only
+        honored if the API server enables the CSIInlineVolume
         feature gate.
         """
         cleaned: typing.List[AllowedCSIDriver] = []
@@ -1712,9 +1717,9 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @property
     def allowed_flex_volumes(self) -> typing.List["AllowedFlexVolume"]:
         """
-        allowedFlexVolumes is a whitelist of allowed Flexvolumes.
-        Empty or nil indicates that all Flexvolumes may be used.
-        This parameter is effective only when the usage of the
+        allowedFlexVolumes is an allowlist of Flexvolumes.  Empty or
+        nil indicates that all Flexvolumes may be used.  This
+        parameter is effective only when the usage of the
         Flexvolumes is allowed in the "volumes" field.
         """
         return typing.cast(
@@ -1727,9 +1732,9 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
         self, value: typing.Union[typing.List["AllowedFlexVolume"], typing.List[dict]]
     ):
         """
-        allowedFlexVolumes is a whitelist of allowed Flexvolumes.
-        Empty or nil indicates that all Flexvolumes may be used.
-        This parameter is effective only when the usage of the
+        allowedFlexVolumes is an allowlist of Flexvolumes.  Empty or
+        nil indicates that all Flexvolumes may be used.  This
+        parameter is effective only when the usage of the
         Flexvolumes is allowed in the "volumes" field.
         """
         cleaned: typing.List[AllowedFlexVolume] = []
@@ -1745,8 +1750,8 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @property
     def allowed_host_paths(self) -> typing.List["AllowedHostPath"]:
         """
-        allowedHostPaths is a white list of allowed host paths.
-        Empty indicates that all host paths may be used.
+        allowedHostPaths is an allowlist of host paths. Empty
+        indicates that all host paths may be used.
         """
         return typing.cast(
             typing.List["AllowedHostPath"],
@@ -1758,8 +1763,8 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
         self, value: typing.Union[typing.List["AllowedHostPath"], typing.List[dict]]
     ):
         """
-        allowedHostPaths is a white list of allowed host paths.
-        Empty indicates that all host paths may be used.
+        allowedHostPaths is an allowlist of host paths. Empty
+        indicates that all host paths may be used.
         """
         cleaned: typing.List[AllowedHostPath] = []
         for item in value:
@@ -1774,7 +1779,7 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @property
     def allowed_proc_mount_types(self) -> typing.List[str]:
         """
-        AllowedProcMountTypes is a whitelist of allowed
+        AllowedProcMountTypes is an allowlist of allowed
         ProcMountTypes. Empty or nil indicates that only the
         DefaultProcMountType may be used. This requires the
         ProcMountType feature flag to be enabled.
@@ -1787,7 +1792,7 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @allowed_proc_mount_types.setter
     def allowed_proc_mount_types(self, value: typing.List[str]):
         """
-        AllowedProcMountTypes is a whitelist of allowed
+        AllowedProcMountTypes is an allowlist of allowed
         ProcMountTypes. Empty or nil indicates that only the
         DefaultProcMountType may be used. This requires the
         ProcMountType feature flag to be enabled.
@@ -1801,7 +1806,7 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
         sysctls, defaults to none. Each entry is either a plain
         sysctl name or ends in "*" in which case it is considered as
         a prefix of allowed sysctls. Single * means all unsafe
-        sysctls are allowed. Kubelet has to whitelist all allowed
+        sysctls are allowed. Kubelet has to allowlist all allowed
         unsafe sysctls explicitly to avoid rejection.
 
         Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc.
@@ -1819,7 +1824,7 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
         sysctls, defaults to none. Each entry is either a plain
         sysctl name or ends in "*" in which case it is considered as
         a prefix of allowed sysctls. Single * means all unsafe
-        sysctls are allowed. Kubelet has to whitelist all allowed
+        sysctls are allowed. Kubelet has to allowlist all allowed
         unsafe sysctls explicitly to avoid rejection.
 
         Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc.
@@ -2218,9 +2223,9 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @property
     def volumes(self) -> typing.List[str]:
         """
-        volumes is a white list of allowed volume plugins. Empty
-        indicates that no volumes may be used. To allow all volumes
-        you may use '*'.
+        volumes is an allowlist of volume plugins. Empty indicates
+        that no volumes may be used. To allow all volumes you may
+        use '*'.
         """
         return typing.cast(
             typing.List[str],
@@ -2230,9 +2235,9 @@ class PodSecurityPolicySpec(_kuber_definitions.Definition):
     @volumes.setter
     def volumes(self, value: typing.List[str]):
         """
-        volumes is a white list of allowed volume plugins. Empty
-        indicates that no volumes may be used. To allow all volumes
-        you may use '*'.
+        volumes is an allowlist of volume plugins. Empty indicates
+        that no volumes may be used. To allow all volumes you may
+        use '*'.
         """
         self._properties["volumes"] = value
 
@@ -2432,7 +2437,7 @@ class RuntimeClassStrategyOptions(_kuber_definitions.Definition):
     @property
     def allowed_runtime_class_names(self) -> typing.List[str]:
         """
-        allowedRuntimeClassNames is a whitelist of RuntimeClass
+        allowedRuntimeClassNames is an allowlist of RuntimeClass
         names that may be specified on a pod. A value of "*" means
         that any RuntimeClass name is allowed, and must be the only
         item in the list. An empty list requires the
@@ -2446,7 +2451,7 @@ class RuntimeClassStrategyOptions(_kuber_definitions.Definition):
     @allowed_runtime_class_names.setter
     def allowed_runtime_class_names(self, value: typing.List[str]):
         """
-        allowedRuntimeClassNames is a whitelist of RuntimeClass
+        allowedRuntimeClassNames is an allowlist of RuntimeClass
         names that may be specified on a pod. A value of "*" means
         that any RuntimeClass name is allowed, and must be the only
         item in the list. An empty list requires the
